@@ -1,4 +1,5 @@
-import staticpipes.rjmin.rjsmin
+import rjsmin
+
 import staticpipes.utils
 from staticpipes.current_info import CurrentInfo
 from staticpipes.pipe_base import BasePipe
@@ -15,18 +16,18 @@ class PipeJavascriptMinifier(BasePipe):
         self.extensions = extensions
 
     def build_file(self, dir: str, filename: str, current_info: CurrentInfo) -> None:
+        """"""
         if self.extensions and not staticpipes.utils.does_filename_have_extension(
             filename, self.extensions
         ):
             return
 
-        f = staticpipes.rjmin.rjsmin._make_jsmin(python_only=True)
-
         self.build_directory.write(
             dir,
             filename,
-            f(self.source_directory.get_contents_as_str(dir, filename)),
+            rjsmin.jsmin(self.source_directory.get_contents_as_str(dir, filename)),
         )
 
     def file_changed_during_watch(self, dir, filename, current_info):
+        """"""
         self.build_file(dir, filename, current_info)
